boto v2.9.7 — boto v2.21.1

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »

# boto v2.9.7

date: | 2013/07/08

This release is primarily a bugfix release, but also inludes support for Elastic Transcoder updates (variable bit rate, max frame rate & watermark features).

## Features

- Added support for selecting specific attributes in DynamoDB v2. (issue 1567, commit d9e5c2)
- Added support for variable bit rate, max frame rate & watermark features in Elastic Transcoder. (commit 3791c9)

## Bugfixes

- Altered RDS to now use SigV4. (commit be1633)

- Removed parsing check in `StorageUri`. (commit 21bc8f)

- More information returned about GS key generation. (issue 1571, commit 6d5e3a)

- Upload handling headers now case-insensitive. (issue 1575, commit 60383d)

- Several CloudFormation timestamp updates. (issue 1582, issue 1583, issue 1588, commit 0a23d34, commit 6d4209)

- Corrected a bug in how limits are handled in DynamoDB v2. (issue 1590, commit 710a62)

- Several documentation improvements/fixes:

  > - Typo in `boto.connection` fixed. (issue 1569, commit cf39fd)
  > - All previous release notes added to the docs. (commit 165596)
  > - Corrected error in `get_all_tags` docs. (commit 4bca5d)
  > - Corrected a typo in the S3 tutorial. (commit f0cef8)
  > - Corrected several import errors in the DDBv2 tutorial. (commit 5401a3)
  > - Fixed an error in the `get_key_pair` docstring. (issue 1590, commit a9cb8d)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »